@@ -1,14 +1,13 @@
-# encoding=UTF-8
-
 # Copyright © 2009-2021 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2022-2024 FriedrichFröbel
 #
-# This file is part of python-djvulibre.
+# This file is part of djvulibre-python.
 #
-# python-djvulibre is free software; you can redistribute it and/or modify it
+# djvulibre-python is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 2 as published by
 # the Free Software Foundation.
 #
-# python-djvulibre is distributed in the hope that it will be useful, but
+# djvulibre-python is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 # or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 # more details.
@@ -26,9 +25,14 @@ source_suffix = '.rst'
 source_encoding = 'UTF-8'
 master_doc = 'index'
 
-import setup as _setup  # noqa: E402
-project = _setup.setup_params['name']
-version = release = _setup.py_version
+try:
+    import setup as _setup  # noqa: E402
+    project = _setup.setup_params['name']
+    version = release = _setup.py_version
+except ImportError:
+    from importlib.metadata import version as _version
+    project = 'djvulibre-python'
+    version = _version(project)
 
 pygments_style = 'sphinx'
 
@@ -64,5 +68,3 @@ def setup(app):
         # deprecated in Sphinx 1.8, removed in 4.0
         add_css_file = app.add_stylesheet
     add_css_file('docutils-math.css')
-
-# vim:ts=4 sts=4 sw=4 et
