@@ -1,14 +1,13 @@
-# encoding=UTF-8
-
 # Copyright © 2007-2022 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2022-2024 FriedrichFroebel
 #
-# This file is part of python-djvulibre.
+# This file is part of djvulibre-python.
 #
-# python-djvulibre is free software; you can redistribute it and/or modify it
+# djvulibre-python is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 2 as published by
 # the Free Software Foundation.
 #
-# python-djvulibre is distributed in the hope that it will be useful, but
+# djvulibre-python is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 # or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 # more details.
@@ -74,6 +73,7 @@ from djvu.sexpr import (
 )
 
 from tools import (
+    IMAGES,
     interim_locale,
     get_changelog_version,
     locale_encoding,
@@ -85,9 +85,6 @@ from tools import (
 )
 
 
-IMAGES = os.path.join(os.path.dirname(__file__), 'images', '')
-
-
 class DecodeTestCase(TestCase):
     def run_command(self, *cmd, **kwargs):
         stdin = kwargs.pop('stdin', None)
@@ -976,5 +973,3 @@ class WildcardImportTestCase(TestCase):
                 'cmp_text_zone'
             ]
         )
-
-# vim:ts=4 sts=4 sw=4 et
